SystemOrganization addCategory: #ConfigurationOfNutcracker!

Object subclass: #ConfigurationOfNutcracker
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfNutcracker'!

!ConfigurationOfNutcracker class methodsFor: 'development support' stamp: 'fbs 1/6/2012 09:38'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfNutcracker class methodsFor: 'private' stamp: 'fbs 1/6/2012 09:38'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfNutcracker class methodsFor: 'private' stamp: 'fbs 4/17/2012 09:35'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := (MCCacheRepository default includesVersionNamed: aString)
		ifTrue: [MCCacheRepository default]
		ifFalse: [MCHttpRepository
				location: aPath
				user: ''
				password: ''].
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfNutcracker class methodsFor: 'private' stamp: 'fbs 4/17/2012 09:35'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."
	| meta |
	meta := 'ConfigurationOfMetacello-dkh.674'.
	Smalltalk at: #MetacelloProject ifAbsent: [
		"list of repositories to try, in case primary repository is not accessible"
		self bootstrapPackage: meta from: 'http://www.squeaksource.com/MetacelloRepository'.
		Smalltalk at: #ConfigurationOfMetacello ifPresent: [:config | config load].
		Smalltalk at: #MetacelloProject ifAbsent: [
			self bootstrapPackage: meta from: 'http://seaside.gemstone.com/ss/metacello'.
			Smalltalk at: #ConfigurationOfMetacello ifPresent: [:config | config load].
			Smalltalk at: #MetacelloProject ifAbsent: [self error: 'Couldn''t load Metacello']]].! !

!ConfigurationOfNutcracker class methodsFor: 'private' stamp: 'fbs 4/17/2012 09:35'!
ensureMetacelloBaseConfiguration
	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self bootstrapPackage: 'Metacello-Base-DaleHenrichs.19' from: 'http://seaside.gemstone.com/ss/metacello']! !

!ConfigurationOfNutcracker class methodsFor: 'metacello tool support' stamp: 'fbs 1/6/2012 09:38'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfNutcracker class methodsFor: 'loading' stamp: 'fbs 1/6/2012 09:38'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfNutcracker class methodsFor: 'loading' stamp: 'fbs 1/6/2012 09:38'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfNutcracker class methodsFor: 'loading' stamp: 'fbs 1/6/2012 09:38'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfNutcracker class methodsFor: 'accessing' stamp: 'fbs 1/6/2012 09:38'!
project

	^self new project! !

!ConfigurationOfNutcracker class methodsFor: 'development support' stamp: 'fbs 1/6/2012 09:38'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfNutcracker methodsFor: 'baselines' stamp: 'fbs 1/6/2012 09:38'!
baseline10: spec
	<version: '1.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://www./squeaksource.com/Nutcracker'.
		spec 
			package: 'AlgebraicDataType';
			package: 'Either' with: [
				spec requires: #('AlgebraicDataType' ). ];
			package: 'EitherTests' with: [
				spec requires: #('Either' 'MonadTests' ). ];
			package: 'Maybe' with: [
				spec requires: #('AlgebraicDataType' ). ];
			package: 'MaybeTests' with: [
				spec requires: #('Maybe' 'MonadTests' ). ];
			package: 'MonadTests';
			package: 'PersistentUnionFind';
			package: 'Unification' with: [
				spec requires: #('PersistentUnionFind' ). ];
			package: 'UnificationTests' with: [
				spec requires: #('AlgebraicDataType' 'Unification' ). ].
		spec 
			group: 'default' with: #('Either' 'Maybe' 'Unification' );
			group: 'minimal' with: #('Unification' );
			group: 'development' with: #('EitherTests' 'MaybeTests' 'UnificationTests' ). ].
! !

!ConfigurationOfNutcracker methodsFor: 'baselines' stamp: 'fbs 2/16/2013 11:25'!
baseline11: spec
	<version: '1.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://ss3.gemstone.com/ss/Nutcracker'.
		spec 
			package: 'AlgebraicDataType';
			package: 'Either' with: [
				spec requires: #('AlgebraicDataType' ). ];
			package: 'EitherTests' with: [
				spec requires: #('Either' 'MonadTests' ). ];
			package: 'Maybe' with: [
				spec requires: #('AlgebraicDataType' ). ];
			package: 'MaybeTests' with: [
				spec requires: #('Maybe' 'MonadTests' ). ];
			package: 'MonadTests';
			package: 'PersistentUnionFind';
			package: 'Unification' with: [
				spec requires: #('AlgebraicDataType' 'PersistentUnionFind' ). ].
		spec 
			group: 'default' with: #('AlgebraicDataType' 'Either' 'Maybe' 'Unification' 'EitherTests' 'MaybeTests'). ].
! !

!ConfigurationOfNutcracker methodsFor: 'symbolic versions' stamp: 'fbs 6/14/2012 09:24'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '1.1-dev'.
! !

!ConfigurationOfNutcracker methodsFor: 'accessing' stamp: 'fbs 4/17/2012 09:36'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfNutcracker methodsFor: 'symbolic versions' stamp: 'fbs 6/14/2012 09:33'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '1.0-dev'.
! !

!ConfigurationOfNutcracker methodsFor: 'versions' stamp: 'fbs 1/6/2012 09:38'!
version10dev: spec
	<version: '1.0-dev' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Initial development version'.
		spec author: 'fbs'.
		spec timestamp: '1/6/2012 09:38'.
		spec 
			package: 'AlgebraicDataType' with: 'AlgebraicDataType-fbs.22';
			package: 'Either' with: 'Either-fbs.6';
			package: 'EitherTests' with: 'EitherTests-fbs.2';
			package: 'Maybe' with: 'Maybe-fbs.7';
			package: 'MaybeTests' with: 'MaybeTests-fbs.2';
			package: 'MonadTests' with: 'MonadTests-fbs.2';
			package: 'PersistentUnionFind' with: 'PersistentUnionFind-fbs.15';
			package: 'Unification' with: 'Unification-fbs.12';
			package: 'UnificationTests' with: 'UnificationTests-fbs.12'. ].
! !

!ConfigurationOfNutcracker methodsFor: 'versions' stamp: 'fbs 6/14/2012 09:31'!
version11dev: spec
	<version: '1.1-dev' imports: #('1.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Initial development version'.
		spec author: 'fbs'.
		spec timestamp: '6/14/2012 09:24'.
		spec 
			package: 'AlgebraicDataType' with: 'AlgebraicDataType-fbs.22';
			package: 'Either' with: 'Either-fbs.9';
			package: 'EitherTests' with: 'EitherTests-fbs.4';
			package: 'Maybe' with: 'Maybe-fbs.9';
			package: 'MaybeTests' with: 'MaybeTests-fbs.3';
			package: 'MonadTests' with: 'MonadTests-fbs.2';
			package: 'PersistentUnionFind' with: 'PersistentUnionFind-fbs.22';
			package: 'Unification' with: 'Unification-fbs.32'. ].
! !
